Documentation technique du back-end — Zds Member 1.0 documentation

# Documentation technique du back-end

Cette documentation est générée à partir des commentaires laissés dans le code source de Zeste de Savoir au format docstring, et qui sont, pour des raisons d’internationalisation, rédigés en anglais.

Vous pouvez également retrouver la documentation fonctionnelle des modules ici.

- Arborescence du back-end
  - Arborescence générale de `zds/`
  - Contenu d’un module
- Les articles (`article/`)
  - Modèles (`models.py`)
  - Vues (`views.py`)
- Les forums (`forum/`)
  - Modèles (`models.py`)
  - Vues (`views.py`)
- Les galleries (`gallery/`)
  - Modèles (`models.py`)
  - Vues (`views.py`)
- Les membres (`member/`)
  - Modèles (`models.py`)
  - Vues (`views.py`)
- Les pages (`pages/`)
  - Vues (`views.py`)
- Les messages privés (`mp/`)
  - Modèles (`models.py`)
  - Vues (`views.py`)
- La recherche (`search/`)
  - Modèles (`models.py`)
  - Vues (`views.py`)
  - Les utilitaires (`utils.py`)
- Les tutoriels (`tutorial/`)
  - Modèles (`models.py`)
  - Vues (`views.py`)
- Les tutoriels v2 (ZEP12) (`tutorialv2/`)
  - Modèles (`models/`)
  - Vues (`views/`)
  - Mixins (`mixins.py`)
  - Les forumulaires (`forms.py`)
  - Les utilitaires (`utils.py`)
- Les utilitaires (`utils/`)
  - Modèles (`models.py`)
  - Articles (`articles.py`)
  - Forums (`forums.py`)
  - Messages privés (`mps.py`)
  - Tutoriels (`tutorials.py`)
  - Les processeurs de contexte (`context_processor.py`)
  - Autres (`misc.py`)